[Libreoffice-commits] .: 2 commits - binfilter/bf_sc binfilter/bf_sch binfilter/bf_sfx2 binfilter/bf_svtools binfilter/bf_svx binfilter/bf_sw binfilter/bf_xmloff binfilter/inc binfilter/legacysmgr filter/inc filter/source oox/inc oox/source writerfilter/inc writerfilter/source writerperfect/source xmerge/source

Caolán McNamara caolan at kemper.freedesktop.org
Mon Dec 6 01:17:12 PST 2010


 binfilter/bf_sc/source/core/data/sc_dociter.cxx                                                  |    2 +-
 binfilter/bf_sc/source/core/data/sc_dpobject.cxx                                                 |    2 +-
 binfilter/bf_sc/source/ui/unoobj/sc_nameuno.cxx                                                  |    2 +-
 binfilter/bf_sch/source/core/sch_memchrt.cxx                                                     |    2 +-
 binfilter/bf_sfx2/source/doc/sfx2_objuno.cxx                                                     |    8 ++++----
 binfilter/bf_svtools/source/numbers/svt_zformat.cxx                                              |    2 +-
 binfilter/bf_svx/util/svx_hidother.src                                                           |    2 +-
 binfilter/bf_sw/source/core/fields/sw_authfld.cxx                                                |    2 +-
 binfilter/bf_sw/source/core/layout/sw_frmtool.cxx                                                |    2 +-
 binfilter/bf_xmloff/source/core/xmloff_xmlerror.cxx                                              |    6 +++---
 binfilter/bf_xmloff/source/core/xmloff_xmlexp.cxx                                                |    8 ++++----
 binfilter/bf_xmloff/source/core/xmloff_xmlimp.cxx                                                |    4 ++--
 binfilter/bf_xmloff/source/style/xmloff_xmlaustp.cxx                                             |    4 ++--
 binfilter/bf_xmloff/source/style/xmloff_xmlnumfi.cxx                                             |    2 +-
 binfilter/bf_xmloff/source/text/xmloff_XMLSectionExport.cxx                                      |    2 +-
 binfilter/bf_xmloff/source/text/xmloff_txtfldi.cxx                                               |    2 +-
 binfilter/inc/bf_sc/dociter.hxx                                                                  |    4 ++--
 binfilter/inc/bf_svtools/zforlist.hxx                                                            |    2 +-
 binfilter/inc/bf_svx/fmhelp.hrc                                                                  |    2 +-
 binfilter/inc/bf_xmloff/xmlerror.hxx                                                             |    4 ++--
 binfilter/inc/bf_xmloff/xmlexp.hxx                                                               |    2 +-
 binfilter/inc/bf_xmloff/xmlimp.hxx                                                               |    2 +-
 binfilter/legacysmgr/source/legacy/legacy_binfilters_smgr.cxx                                    |   10 +++++-----
 filter/inc/filter/msfilter/escherex.hxx                                                          |    2 +-
 filter/inc/filter/msfilter/mscodec.hxx                                                           |    4 ++--
 filter/source/config/cache/filtercache.hxx                                                       |    6 +++---
 filter/source/config/cache/typedetection.cxx                                                     |    4 ++--
 filter/source/flash/swfwriter.cxx                                                                |    2 +-
 filter/source/msfilter/countryid.cxx                                                             |    2 +-
 filter/source/xmlfilterdetect/filterdetect.cxx                                                   |    2 +-
 filter/source/xslt/import/wordml/wordml2ooo_path.xsl                                             |   10 +++++-----
 oox/inc/oox/core/binarycodec.hxx                                                                 |    8 ++++----
 oox/inc/oox/helper/propertyset.hxx                                                               |    2 +-
 oox/source/export/preset-definitions-to-shape-types.pl                                           |    2 +-
 oox/source/vml/vmlinputstream.cxx                                                                |    4 ++--
 writerfilter/inc/resourcemodel/TableManager.hxx                                                  |    2 +-
 writerfilter/source/dmapper/PropertyMap.cxx                                                      |    2 +-
 writerperfect/source/filter/DocumentCollector.cxx                                                |    4 ++--
 xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentDeserializerImpl.java |    2 +-
 xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentSerializerImpl.java   |    2 +-
 40 files changed, 69 insertions(+), 69 deletions(-)

New commits:
commit 018e0db20001b439a5c92a2cec21bfcf187d8587
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Sat Dec 4 13:02:52 2010 +0900

    Replace all occured, occurance etc.

diff --git a/binfilter/bf_sc/source/core/data/sc_dociter.cxx b/binfilter/bf_sc/source/core/data/sc_dociter.cxx
index abcf5a1..15374df 100644
--- a/binfilter/bf_sc/source/core/data/sc_dociter.cxx
+++ b/binfilter/bf_sc/source/core/data/sc_dociter.cxx
@@ -632,7 +632,7 @@ BOOL ScValueIterator::GetNext(double& rValue, USHORT& rErr)
 /*N*/                 }
 /*N*/                 else if ( nStopOnMismatch )
 /*N*/                 {
-/*N*/                     nStopOnMismatch |= nStopOnMismatchOccured;
+/*N*/                     nStopOnMismatch |= nStopOnMismatchOccurred;
 /*N*/                     // Yes, even a mismatch may have a fulfilled equal
 /*N*/                     // condition if regular expressions were involved and
 /*N*/                     // SC_LESS_EQUAL or SC_GREATER_EQUAL were queried.
diff --git a/binfilter/bf_sc/source/core/data/sc_dpobject.cxx b/binfilter/bf_sc/source/core/data/sc_dpobject.cxx
index b4c128f..44a950a 100644
--- a/binfilter/bf_sc/source/core/data/sc_dpobject.cxx
+++ b/binfilter/bf_sc/source/core/data/sc_dpobject.cxx
@@ -393,7 +393,7 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	if ( pServDesc && rDesc == *pServDesc )
 /*N*/ 	USHORT nOutCount = 0;
 /*N*/ 	BOOL bDataFound = FALSE;
 /*N*/ 
-/*N*/ 	//!	merge multiple occurences (data field with different functions)
+/*N*/ 	//!	merge multiple occurrences (data field with different functions)
 /*N*/ 	//!	force data field in one dimension
 /*N*/ 
 /*N*/ 	long nPos[PIVOT_MAXFIELD];
diff --git a/binfilter/bf_sc/source/ui/unoobj/sc_nameuno.cxx b/binfilter/bf_sc/source/ui/unoobj/sc_nameuno.cxx
index 1dcd704..d6d8c9f 100644
--- a/binfilter/bf_sc/source/ui/unoobj/sc_nameuno.cxx
+++ b/binfilter/bf_sc/source/ui/unoobj/sc_nameuno.cxx
@@ -190,7 +190,7 @@ void SAL_CALL ScNamedRangeObj::setName( const ::rtl::OUString& aNewName )
     String aNewStr = aNewName;
     Modify_Impl( &aNewStr, NULL, NULL, NULL );
 
-    if ( aName != aNewStr )					// some error occured...
+    if ( aName != aNewStr )					// some error occurred...
         throw uno::RuntimeException();		// no other exceptions specified
 }
 
diff --git a/binfilter/bf_sch/source/core/sch_memchrt.cxx b/binfilter/bf_sch/source/core/sch_memchrt.cxx
index d397560..71d5af6 100644
--- a/binfilter/bf_sch/source/core/sch_memchrt.cxx
+++ b/binfilter/bf_sch/source/core/sch_memchrt.cxx
@@ -991,7 +991,7 @@ using namespace ::com::sun::star;
 /*N*/                 nStartPos, nEndPos - 1,
 /*N*/                 maChartRange.maRanges[ i ] ))
 /*N*/         {
-/*N*/             // if an error occured, bail out
+/*N*/             // if an error occurred, bail out
 /*N*/             maChartRange.maRanges.clear();
 /*N*/             break;
 /*N*/         }
diff --git a/binfilter/bf_svtools/source/numbers/svt_zformat.cxx b/binfilter/bf_svtools/source/numbers/svt_zformat.cxx
index 15bea86..4d99022 100644
--- a/binfilter/bf_svtools/source/numbers/svt_zformat.cxx
+++ b/binfilter/bf_svtools/source/numbers/svt_zformat.cxx
@@ -529,7 +529,7 @@ SvNumberformat::SvNumberformat(String& rString,
         bStarFlag( FALSE )
 {
     // If the group (AKA thousand) separator is a Non-Breaking Space (French)
-    // replace all occurences by a simple space.
+    // replace all occurrences by a simple space.
     // The tokens will be changed to the LocaleData separator again later on.
     const sal_Unicode cNBSp = 0xA0;
     const String& rThSep = GetFormatter().GetNumThousandSep();
diff --git a/binfilter/bf_svx/util/svx_hidother.src b/binfilter/bf_svx/util/svx_hidother.src
index 721da44..629844c 100644
--- a/binfilter/bf_svx/util/svx_hidother.src
+++ b/binfilter/bf_svx/util/svx_hidother.src
@@ -180,7 +180,7 @@ hidspecial HID_EVT_CONFIRMDELETE			{ HelpID =HID_EVT_CONFIRMDELETE		;};
 hidspecial HID_EVT_ELEMENTINSERTED			{ HelpID =HID_EVT_ELEMENTINSERTED	;};
 hidspecial HID_EVT_ELEMENTREMOVED			{ HelpID =HID_EVT_ELEMENTREMOVED	;};
 hidspecial HID_EVT_ELEMENTREPLACED			{ HelpID =HID_EVT_ELEMENTREPLACED	;};
-hidspecial HID_EVT_ERROROCCURED				{ HelpID =HID_EVT_ERROROCCURED		;};
+hidspecial HID_EVT_ERROROCCURRED				{ HelpID =HID_EVT_ERROROCCURRED		;};
 hidspecial HID_EVT_FIRING					{ HelpID =HID_EVT_FIRING			;};
 hidspecial HID_EVT_FOCUSGAINED				{ HelpID =HID_EVT_FOCUSGAINED		;};
 hidspecial HID_EVT_FOCUSLOST				{ HelpID =HID_EVT_FOCUSLOST			;};
diff --git a/binfilter/bf_sw/source/core/fields/sw_authfld.cxx b/binfilter/bf_sw/source/core/fields/sw_authfld.cxx
index 289ca69..63deca9 100644
--- a/binfilter/bf_sw/source/core/fields/sw_authfld.cxx
+++ b/binfilter/bf_sw/source/core/fields/sw_authfld.cxx
@@ -414,7 +414,7 @@ USHORT  SwAuthorityFieldType::GetSequencePos(long nHandle)
                     SwTOXSortTabBase* pOld = aSortArr[i];
                     if(*pOld == *pNew)
                     {
-                        //only the first occurence in the document
+                        //only the first occurrence in the document
                         //has to be in the array
                         if(*pOld < *pNew)
                             DELETEZ(pNew);
diff --git a/binfilter/bf_sw/source/core/layout/sw_frmtool.cxx b/binfilter/bf_sw/source/core/layout/sw_frmtool.cxx
index 0d230db..1a30f1b 100644
--- a/binfilter/bf_sw/source/core/layout/sw_frmtool.cxx
+++ b/binfilter/bf_sw/source/core/layout/sw_frmtool.cxx
@@ -796,7 +796,7 @@ namespace binfilter {
                         // The layout is calculated _before_ calling PrtOLENotify,
                         // and the OLE objects are not invalidated during import.
                         // Therefore I added the condition !IsUpdateExpFld,
-                        // have a look at the occurence of CalcLayout in
+                        // have a look at the occurrence of CalcLayout in
                         // uiview/view.cxx.
 /*N*/                         if ( !pNd->IsOLESizeInvalid() &&
 /*N*/                              !pSh->GetDoc()->IsUpdateExpFld() )
diff --git a/binfilter/bf_xmloff/source/core/xmloff_xmlerror.cxx b/binfilter/bf_xmloff/source/core/xmloff_xmlerror.cxx
index 2b9eb3a..17766e3 100644
--- a/binfilter/bf_xmloff/source/core/xmloff_xmlerror.cxx
+++ b/binfilter/bf_xmloff/source/core/xmloff_xmlerror.cxx
@@ -77,8 +77,8 @@ public:
     OUString sExceptionMessage;/// message of original exception (if available)
 
     // XLocator information:
-    sal_Int32 nRow;     /// row number where error occured (or -1 for unknown)
-    sal_Int32 nColumn;  /// column number where error occured (or -1)
+    sal_Int32 nRow;     /// row number where error occurred (or -1 for unknown)
+    sal_Int32 nColumn;  /// column number where error occurred (or -1)
     OUString sPublicId; /// public identifier
     OUString sSystemId; /// public identifier
 
@@ -133,7 +133,7 @@ void XMLErrors::AddRecord(
 
     OUStringBuffer sMessage;
 
-    sMessage.appendAscii( "An error or a warning has occured during XML import/export!\n" );
+    sMessage.appendAscii( "An error or a warning has occurred during XML import/export!\n" );
 
     // ID & flags
     sMessage.appendAscii( "Error-Id: 0x");
diff --git a/binfilter/bf_xmloff/source/core/xmloff_xmlimp.cxx b/binfilter/bf_xmloff/source/core/xmloff_xmlimp.cxx
index 0b58479..e65b9d8 100644
--- a/binfilter/bf_xmloff/source/core/xmloff_xmlimp.cxx
+++ b/binfilter/bf_xmloff/source/core/xmloff_xmlimp.cxx
@@ -1275,9 +1275,9 @@ void SvXMLImport::SetError(
 {
     // maintain error flags
     if ( ( nId & XMLERROR_FLAG_ERROR ) != 0 )
-        mnErrorFlags |= ERROR_ERROR_OCCURED;
+        mnErrorFlags |= ERROR_ERROR_OCCURRED;
     if ( ( nId & XMLERROR_FLAG_WARNING ) != 0 )
-        mnErrorFlags |= ERROR_WARNING_OCCURED;
+        mnErrorFlags |= ERROR_WARNING_OCCURRED;
     if ( ( nId & XMLERROR_FLAG_SEVERE ) != 0 )
         mnErrorFlags |= ERROR_DO_NOTHING;
 
diff --git a/binfilter/bf_xmloff/source/style/xmloff_xmlaustp.cxx b/binfilter/bf_xmloff/source/style/xmloff_xmlaustp.cxx
index dde02a2..5b3304c 100644
--- a/binfilter/bf_xmloff/source/style/xmloff_xmlaustp.cxx
+++ b/binfilter/bf_xmloff/source/style/xmloff_xmlaustp.cxx
@@ -115,7 +115,7 @@ void SvXMLAutoStylePoolP::exportStyleAttributes(
                         if (bFoundControlShapeDataStyle)
                         {
                             DBG_ERROR("SvXMLAutoStylePoolP::exportStyleAttributes: found two properties with the ControlShapeDataStyle context id!");
-                            // already added the attribute for the first occurence
+                            // already added the attribute for the first occurrence
                             break;
                         }
 
@@ -130,7 +130,7 @@ void SvXMLAutoStylePoolP::exportStyleAttributes(
                         if (bFoundNumberingRulesName)
                         {
                             DBG_ERROR("SvXMLAutoStylePoolP::exportStyleAttributes: found two properties with the numbering rules name context id!");
-                            // already added the attribute for the first occurence
+                            // already added the attribute for the first occurrence
                             break;
                         }
 
diff --git a/binfilter/bf_xmloff/source/style/xmloff_xmlnumfi.cxx b/binfilter/bf_xmloff/source/style/xmloff_xmlnumfi.cxx
index 368441a..8f2137e 100644
--- a/binfilter/bf_xmloff/source/style/xmloff_xmlnumfi.cxx
+++ b/binfilter/bf_xmloff/source/style/xmloff_xmlnumfi.cxx
@@ -807,7 +807,7 @@ void lcl_EnquoteIfNecessary( ::rtl::OUStringBuffer& rContent, sal_uInt16 nFormat
     else if ( nFormatType == XML_TOK_STYLES_PERCENTAGE_STYLE && nLength > 1 )
     {
         //	the percent character in percentage styles must be left out of quoting
-        //	(one occurence is enough even if there are several percent characters in the string)
+        //	(one occurrence is enough even if there are several percent characters in the string)
 
         ::rtl::OUString aString( rContent.getStr() );
         sal_Int32 nPos = aString.indexOf( (sal_Unicode) '%' );
diff --git a/binfilter/bf_xmloff/source/text/xmloff_XMLSectionExport.cxx b/binfilter/bf_xmloff/source/text/xmloff_XMLSectionExport.cxx
index 7207b7b..af94f35 100644
--- a/binfilter/bf_xmloff/source/text/xmloff_XMLSectionExport.cxx
+++ b/binfilter/bf_xmloff/source/text/xmloff_XMLSectionExport.cxx
@@ -899,7 +899,7 @@ void XMLSectionExport::ExportBaseIndexSource(
         aAny = xLevelTemplates->getByIndex(i);
         aAny >>= aTemplateSequence;
 
-        // export the sequence (abort export if an error occured; #91214#)
+        // export the sequence (abort export if an error occurred; #91214#)
         sal_Bool bResult = 
             ExportIndexTemplate(eType, i, rPropertySet, aTemplateSequence);
         if ( !bResult )
diff --git a/binfilter/bf_xmloff/source/text/xmloff_txtfldi.cxx b/binfilter/bf_xmloff/source/text/xmloff_txtfldi.cxx
index 247dd82..85605c7 100644
--- a/binfilter/bf_xmloff/source/text/xmloff_txtfldi.cxx
+++ b/binfilter/bf_xmloff/source/text/xmloff_txtfldi.cxx
@@ -3179,7 +3179,7 @@ void XMLDdeFieldDeclImportContext::StartElement(
                                                  UNO_QUERY);
         if( xFactory.is() )
         {
-            /* #i6432# There might be multiple occurances of one DDE
+            /* #i6432# There might be multiple occurrences of one DDE
                declaration if it is used in more than one of
                header/footer/body. createInstance will throw an exception if we
                try to create the second, third, etc. instance of such a
diff --git a/binfilter/inc/bf_sc/dociter.hxx b/binfilter/inc/bf_sc/dociter.hxx
index ad1461e..199045f 100644
--- a/binfilter/inc/bf_sc/dociter.hxx
+++ b/binfilter/inc/bf_sc/dociter.hxx
@@ -146,8 +146,8 @@ class ScQueryCellIterator           // alle nichtleeren Zellen in einem Bereich
     {
         nStopOnMismatchDisabled = 0x00,
         nStopOnMismatchEnabled  = 0x01,
-        nStopOnMismatchOccured  = 0x02,
-        nStopOnMismatchExecuted = nStopOnMismatchEnabled | nStopOnMismatchOccured
+        nStopOnMismatchOccurred  = 0x02,
+        nStopOnMismatchExecuted = nStopOnMismatchEnabled | nStopOnMismatchOccurred
     };
 
     enum TestEqualConditionBits
diff --git a/binfilter/inc/bf_svtools/zforlist.hxx b/binfilter/inc/bf_svtools/zforlist.hxx
index 80fbf76..4a72b35 100644
--- a/binfilter/inc/bf_svtools/zforlist.hxx
+++ b/binfilter/inc/bf_svtools/zforlist.hxx
@@ -371,7 +371,7 @@ public:
         @return
             <TRUE/> if string new and ok and inserted.
              <FALSE/> if string already exists or an unresolvable parse error
-             occured, in which case nCheckPos is the error position within rString.
+             occurred, in which case nCheckPos is the error position within rString.
             If the error occurs at position 0 or rString is empty nCheckPos
             will be 1, so an error in the string is always indicated by
              nCheckPos not being zero.
diff --git a/binfilter/inc/bf_svx/fmhelp.hrc b/binfilter/inc/bf_svx/fmhelp.hrc
index e00bdfb..ecc7832 100644
--- a/binfilter/inc/bf_svx/fmhelp.hrc
+++ b/binfilter/inc/bf_svx/fmhelp.hrc
@@ -188,7 +188,7 @@
 #define HID_EVT_ELEMENTINSERTED					(HID_EVT_START +  13)
 #define HID_EVT_ELEMENTREMOVED					(HID_EVT_START +  14)
 #define HID_EVT_ELEMENTREPLACED					(HID_EVT_START +  15)
-#define HID_EVT_ERROROCCURED					(HID_EVT_START +  16)
+#define HID_EVT_ERROROCCURRED					(HID_EVT_START +  16)
 #define HID_EVT_FIRING							(HID_EVT_START +  17)
 #define HID_EVT_FOCUSGAINED						(HID_EVT_START +  18)
 #define HID_EVT_FOCUSLOST						(HID_EVT_START +  19)
diff --git a/binfilter/inc/bf_xmloff/xmlerror.hxx b/binfilter/inc/bf_xmloff/xmlerror.hxx
index a0f8db6..4ca01ea 100644
--- a/binfilter/inc/bf_xmloff/xmlerror.hxx
+++ b/binfilter/inc/bf_xmloff/xmlerror.hxx
@@ -86,8 +86,8 @@ namespace binfilter {
 // SvXMLExport/SvXMLImport error flags
 #define ERROR_NO                0x0000
 #define ERROR_DO_NOTHING        0x0001
-#define ERROR_ERROR_OCCURED     0x0002
-#define ERROR_WARNING_OCCURED   0x0004
+#define ERROR_ERROR_OCCURRED     0x0002
+#define ERROR_WARNING_OCCURRED   0x0004
 
 
 class ErrorRecord;
diff --git a/binfilter/inc/bf_xmloff/xmlexp.hxx b/binfilter/inc/bf_xmloff/xmlexp.hxx
index ff22a96..732d84d 100644
--- a/binfilter/inc/bf_xmloff/xmlexp.hxx
+++ b/binfilter/inc/bf_xmloff/xmlexp.hxx
@@ -416,7 +416,7 @@ public:
     void IgnorableWhitespace();
 
     /**
-     * Record an error condition that occured during export. The
+     * Record an error condition that occurred during export. The
      * behavior of SetError can be modified using the error flag
      * constants.
      */
diff --git a/binfilter/inc/bf_xmloff/xmlimp.hxx b/binfilter/inc/bf_xmloff/xmlimp.hxx
index 169d7e4..3b85f29 100644
--- a/binfilter/inc/bf_xmloff/xmlimp.hxx
+++ b/binfilter/inc/bf_xmloff/xmlimp.hxx
@@ -318,7 +318,7 @@ public:
 #endif
 
     /**
-     * Record an error condition that occured during import. The
+     * Record an error condition that occurred during import. The
      * behavior of SetError can be modified using the error flag
      * constants.
      */
diff --git a/binfilter/legacysmgr/source/legacy/legacy_binfilters_smgr.cxx b/binfilter/legacysmgr/source/legacy/legacy_binfilters_smgr.cxx
index 7c69323..ddda91e 100644
--- a/binfilter/legacysmgr/source/legacy/legacy_binfilters_smgr.cxx
+++ b/binfilter/legacysmgr/source/legacy/legacy_binfilters_smgr.cxx
@@ -686,7 +686,7 @@ void OServiceManager::onUnloadingNotify()
     IT_MM it_end1= m_ServiceMap.end();
     list<IT_MM> listDeleteServiceMap;
     typedef list<IT_MM>::const_iterator CIT_DMM;
-    // find occurences in m_ServiceMap
+    // find occurrences in m_ServiceMap
     for(IT_MM it_i1= m_ServiceMap.begin(); it_i1 != it_end1; it_i1++)
     {
         if( m_SetLoadedFactories.find( it_i1->second) != it_SetEnd)
@@ -798,7 +798,7 @@ void OServiceManager::disposing()
         {
 #ifdef DEBUG
             OString str( OUStringToOString( exc.Message, RTL_TEXTENCODING_ASCII_US ) );
-            OSL_TRACE( "### RuntimeException occured upon disposing factory: %s", str.getStr() );
+            OSL_TRACE( "### RuntimeException occurred upon disposing factory: %s", str.getStr() );
 #endif
         }
     }
@@ -1008,7 +1008,7 @@ Reference< XInterface > OServiceManager::createInstanceWithContext(
         {
 #ifdef DEBUG
             OString str( OUStringToOString( exc.Message, RTL_TEXTENCODING_ASCII_US ) );
-            OSL_TRACE( "### DisposedException occured: %s", str.getStr() );
+            OSL_TRACE( "### DisposedException occurred: %s", str.getStr() );
 #endif
         }
     }
@@ -1057,7 +1057,7 @@ Reference< XInterface > OServiceManager::createInstanceWithArgumentsAndContext(
         {
 #ifdef DEBUG
             OString str( OUStringToOString( exc.Message, RTL_TEXTENCODING_ASCII_US ) );
-            OSL_TRACE( "### DisposedException occured: %s", str.getStr() );
+            OSL_TRACE( "### DisposedException occurred: %s", str.getStr() );
 #endif
         }
     }
@@ -2076,7 +2076,7 @@ void * SAL_CALL legacysmgr_component_getFactory(
         OUStringBuffer buf( 128 );
         buf.appendAscii(
             RTL_CONSTASCII_STRINGPARAM(
-                "### unexpected exception occured in binfilters "
+                "### unexpected exception occurred in binfilters "
                 "component_getFactory(): ") );
         buf.append( exc.Message );
         OString cstr(
diff --git a/filter/inc/filter/msfilter/escherex.hxx b/filter/inc/filter/msfilter/escherex.hxx
index 436784b..67843eb 100644
--- a/filter/inc/filter/msfilter/escherex.hxx
+++ b/filter/inc/filter/msfilter/escherex.hxx
@@ -312,7 +312,7 @@
 
 enum ESCHER_BlibType
 {							// GEL provided types...
-   ERROR = 0,				// An error occured during loading
+   ERROR = 0,				// An error occurred during loading
    UNKNOWN,					// An unknown blip type
    EMF,						// Windows Enhanced Metafile
    WMF,						// Windows Metafile
diff --git a/filter/inc/filter/msfilter/mscodec.hxx b/filter/inc/filter/msfilter/mscodec.hxx
index a03c1dc..c3ebd6d 100644
--- a/filter/inc/filter/msfilter/mscodec.hxx
+++ b/filter/inc/filter/msfilter/mscodec.hxx
@@ -257,7 +257,7 @@ public:
             Size of the destination buffer.
 
         @return
-            true = Encoding was successful (no error occured).
+            true = Encoding was successful (no error occurred).
     */
     bool                Encode(
                             const void* pData, sal_Size nDatLen,
@@ -283,7 +283,7 @@ public:
             Size of the destination buffer.
 
         @return
-            true = Decoding was successful (no error occured).
+            true = Decoding was successful (no error occurred).
     */
     bool                Decode(
                             const void* pData, sal_Size nDatLen,
diff --git a/filter/source/config/cache/filtercache.hxx b/filter/source/config/cache/filtercache.hxx
index fb91460..b655681 100644
--- a/filter/source/config/cache/filtercache.hxx
+++ b/filter/source/config/cache/filtercache.hxx
@@ -587,7 +587,7 @@ class FilterCache : public BaseLock
                         attributes there.
 
             @throw      [css::uno::Exception]
-                        if an internal error occured.
+                        if an internal error occurred.
                         Note: If the item is missing inside the underlying configuration
                         no exception will be thrown. In such case the item is marked as
                         finalized/mandatory automaticly
@@ -740,7 +740,7 @@ class FilterCache : public BaseLock
 
             @return     [css::uno::Any]
                         the value of the requested key.
-                        Can be empty if an internal error occured or if the requested
+                        Can be empty if an internal error occurred or if the requested
                         key does not exists!
          */
         css::uno::Any impl_getDirectCFGValue(const ::rtl::OUString& sDirectKey);
@@ -898,7 +898,7 @@ class FilterCache : public BaseLock
                     the set node name of the requested item.
 
             @return An iterator, which points directly to the new cached item.
-                    Is a valid iterator if no exception occured here!
+                    Is a valid iterator if no exception occurred here!
                     But to improve robustness - it should be checked :-)
 
             @throw  [css::container::NoSuchElementException]
diff --git a/filter/source/config/cache/typedetection.cxx b/filter/source/config/cache/typedetection.cxx
index 826754c..8f4beee 100644
--- a/filter/source/config/cache/typedetection.cxx
+++ b/filter/source/config/cache/typedetection.cxx
@@ -182,7 +182,7 @@ TypeDetection::~TypeDetection()
 
         //*******************************************
         // if no flat detected (nor preselected!) type could be
-        // verified and no error occured during creation of
+        // verified and no error occurred during creation of
         // the might needed input stream, start detection
         // which uses all registered deep detection services.
         if (
@@ -741,7 +741,7 @@ void TypeDetection::impl_getPreselection(const css::util::URL&                aP
     // a) no types                                => no detection
     // b) deep detection not allowed              => return first valid type of list (because its the preferred or the first valid one)
     //    or(!) match by URLPattern               => in such case a deep detection will be supressed!
-    // c) type has no detect service              => safe the first occured type without a detect service
+    // c) type has no detect service              => safe the first occurred type without a detect service
     //                                               as "last chance"(!). It will be used outside of this method
     //                                               if no further type could be detected.
     //                                               It must be the first one, because it can be a preferred type.
diff --git a/filter/source/flash/swfwriter.cxx b/filter/source/flash/swfwriter.cxx
index 9f0a818..fa7dd63 100644
--- a/filter/source/flash/swfwriter.cxx
+++ b/filter/source/flash/swfwriter.cxx
@@ -550,7 +550,7 @@ sal_Bool Writer::streamSound( const char * filename )
 // not the sum of the number of samples in the L and R channels.
 // 
 // The return code = number of bytes output in mp3buffer.  This can be 0.
-// If it is <0, an error occured.
+// If it is <0, an error occurred.
 
 
         for (int samples_written = 0; samples_written < info.frames; samples_written += samples_per_frame)
diff --git a/filter/source/msfilter/countryid.cxx b/filter/source/msfilter/countryid.cxx
index c534e8e..df75753 100644
--- a/filter/source/msfilter/countryid.cxx
+++ b/filter/source/msfilter/countryid.cxx
@@ -331,7 +331,7 @@ CountryId ConvertLanguageToCountry( LanguageType eLanguage )
 
 LanguageType ConvertCountryToLanguage( CountryId eCountry )
 {
-    // just find the first occurance of eCountry and return the language type
+    // just find the first occurrence of eCountry and return the language type
     const CountryEntry* pEntry = std::find_if( pTable, pEnd, CountryEntryPred_Country( eCountry ) );
     return (pEntry != pEnd) ? pEntry->meLanguage : LANGUAGE_DONTKNOW;
 }
diff --git a/filter/source/xmlfilterdetect/filterdetect.cxx b/filter/source/xmlfilterdetect/filterdetect.cxx
index e00d022..107de47 100644
--- a/filter/source/xmlfilterdetect/filterdetect.cxx
+++ b/filter/source/xmlfilterdetect/filterdetect.cxx
@@ -187,7 +187,7 @@ Reference< com::sun::star::frame::XModel > xModel;
         }
         catch(Exception &)
         {
-                 OSL_ENSURE( sal_False, "An Exception occured while opening File stream" );
+                 OSL_ENSURE( sal_False, "An Exception occurred while opening File stream" );
         }
         if(sTypeName.equalsAscii(""))
         {
diff --git a/filter/source/xslt/import/wordml/wordml2ooo_path.xsl b/filter/source/xslt/import/wordml/wordml2ooo_path.xsl
index 2ad46a1..736d62a 100644
--- a/filter/source/xslt/import/wordml/wordml2ooo_path.xsl
+++ b/filter/source/xslt/import/wordml/wordml2ooo_path.xsl
@@ -1533,7 +1533,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'n' ">
@@ -1550,7 +1550,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'w' ">
@@ -1567,7 +1567,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'q' ">
@@ -1585,7 +1585,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'h' ">
@@ -1601,7 +1601,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="string-length(translate($curr-char ,  'mlcxetrv' ,'')) = 0 ">
diff --git a/oox/inc/oox/core/binarycodec.hxx b/oox/inc/oox/core/binarycodec.hxx
index 1512532..a577704 100644
--- a/oox/inc/oox/core/binarycodec.hxx
+++ b/oox/inc/oox/core/binarycodec.hxx
@@ -127,7 +127,7 @@ public:
             this size.
 
         @return
-            True = decoding was successful (no error occured).
+            True = decoding was successful (no error occurred).
     */
     bool                decode(
                             sal_uInt8* pnDestData,
@@ -147,7 +147,7 @@ public:
             Number of bytes to be skipped (cipher "seeks" forward).
 
         @return
-            True = skip was successful (no error occured).
+            True = skip was successful (no error occurred).
      */
     bool                skip( sal_Int32 nBytes );
 
@@ -254,7 +254,7 @@ public:
             this size.
 
         @return
-            True = decoding was successful (no error occured).
+            True = decoding was successful (no error occurred).
     */
     bool                decode(
                             sal_uInt8* pnDestData,
@@ -274,7 +274,7 @@ public:
             Number of bytes to be skipped (cipher "seeks" forward).
 
         @return
-            True = skip was successful (no error occured).
+            True = skip was successful (no error occurred).
      */
     bool                skip( sal_Int32 nBytes );
 
diff --git a/oox/inc/oox/helper/propertyset.hxx b/oox/inc/oox/helper/propertyset.hxx
index 54b8de5..ef95710 100644
--- a/oox/inc/oox/helper/propertyset.hxx
+++ b/oox/inc/oox/helper/propertyset.hxx
@@ -98,7 +98,7 @@ public:
     ::com::sun::star::uno::Any getAnyProperty( sal_Int32 nPropId ) const;
 
     /** Gets the specified boolean property from the property set.
-        @return  true = property contains true; false = property contains false or error occured. */
+        @return  true = property contains true; false = property contains false or error occurred. */
     bool                getBoolProperty( sal_Int32 nPropId ) const;
 
     /** Gets the specified properties from the property set. Tries to use the XMultiPropertySet interface.
diff --git a/oox/source/export/preset-definitions-to-shape-types.pl b/oox/source/export/preset-definitions-to-shape-types.pl
index bc5163b..6427a4b 100644
--- a/oox/source/export/preset-definitions-to-shape-types.pl
+++ b/oox/source/export/preset-definitions-to-shape-types.pl
@@ -288,7 +288,7 @@ $path_h = 1;
     201 => 'hostControl', # should not be used
     202 => 'textBox'
 );
-# An error occured, we have to ignore this shape
+# An error occurred, we have to ignore this shape
 sub error( $ )
 {
     my ( $msg ) = @_;
diff --git a/oox/source/vml/vmlinputstream.cxx b/oox/source/vml/vmlinputstream.cxx
index 7541e48..57b9391 100644
--- a/oox/source/vml/vmlinputstream.cxx
+++ b/oox/source/vml/vmlinputstream.cxx
@@ -89,7 +89,7 @@ inline void lclAppendToBuffer( OStringBuffer& rBuffer, const sal_Char* pcBeg, co
 void lclProcessAttribs( OStringBuffer& rBuffer, const sal_Char* pcBeg, const sal_Char* pcEnd )
 {
     /*  Map attribute names to char-pointer of all attributes. This map is used
-        to find multiple occurences of attributes with the same name. The
+        to find multiple occurrences of attributes with the same name. The
         mapped pointers are used as map key in the next map below. */
     typedef ::std::map< OString, const sal_Char* > AttributeNameMap;
     AttributeNameMap aAttributeNames;
@@ -140,7 +140,7 @@ void lclProcessAttribs( OStringBuffer& rBuffer, const sal_Char* pcBeg, const sal
         }
     }
 
-    // if no error has occured, build the resulting attribute list
+    // if no error has occurred, build the resulting attribute list
     if( bOk )
         for( AttributeDataMap::iterator aIt = aAttributes.begin(), aEnd = aAttributes.end(); aIt != aEnd; ++aIt )
             rBuffer.append( ' ' ).append( aIt->second );
diff --git a/writerfilter/inc/resourcemodel/TableManager.hxx b/writerfilter/inc/resourcemodel/TableManager.hxx
index b39ac3c..86b2d62 100644
--- a/writerfilter/inc/resourcemodel/TableManager.hxx
+++ b/writerfilter/inc/resourcemodel/TableManager.hxx
@@ -542,7 +542,7 @@ public:
     virtual void props(PropertiesPointer pProps);
 
     /**
-       Handle occurance of character 0x7.
+       Handle occurrence of character 0x7.
      */
     virtual void handle0x7();
 
diff --git a/writerfilter/source/dmapper/PropertyMap.cxx b/writerfilter/source/dmapper/PropertyMap.cxx
index 73c22b6..f012e76 100644
--- a/writerfilter/source/dmapper/PropertyMap.cxx
+++ b/writerfilter/source/dmapper/PropertyMap.cxx
@@ -724,7 +724,7 @@ void SectionPropertyMap::CopyLastHeaderFooter( bool bFirstPage, DomainMapper_Imp
         catch ( const uno::Exception& e )
         {
 #if DEBUG
-            clog << "An exception occured in SectionPropertyMap::CopyLastHeaderFooter( ) - ";
+            clog << "An exception occurred in SectionPropertyMap::CopyLastHeaderFooter( ) - ";
             clog << rtl::OUStringToOString( e.Message, RTL_TEXTENCODING_UTF8 ).getStr( ) << endl;
 #endif
         }
diff --git a/writerperfect/source/filter/DocumentCollector.cxx b/writerperfect/source/filter/DocumentCollector.cxx
index 4286f8a..1ef8dcc 100644
--- a/writerperfect/source/filter/DocumentCollector.cxx
+++ b/writerperfect/source/filter/DocumentCollector.cxx
@@ -460,7 +460,7 @@ void DocumentCollector::openHeader(const WPXPropertyList &propList)
 {
     std::vector<DocumentElement *> * pHeaderFooterContentElements = new std::vector<DocumentElement *>;
 
-    if (propList["libwpd:occurence"]->getStr() == "even")
+    if (propList["libwpd:occurrence"]->getStr() == "even")
                 mpCurrentPageSpan->setHeaderLeftContent(pHeaderFooterContentElements);
         else
                 mpCurrentPageSpan->setHeaderContent(pHeaderFooterContentElements);
@@ -477,7 +477,7 @@ void DocumentCollector::openFooter(const WPXPropertyList &propList)
 {
     std::vector<DocumentElement *> * pHeaderFooterContentElements = new std::vector<DocumentElement *>;
 
-    if (propList["libwpd:occurence"]->getStr() == "even")
+    if (propList["libwpd:occurrence"]->getStr() == "even")
                 mpCurrentPageSpan->setFooterLeftContent(pHeaderFooterContentElements);
         else
                 mpCurrentPageSpan->setFooterContent(pHeaderFooterContentElements);
diff --git a/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentDeserializerImpl.java b/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentDeserializerImpl.java
index b644069..1da5f0b 100644
--- a/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentDeserializerImpl.java
+++ b/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentDeserializerImpl.java
@@ -231,7 +231,7 @@ public final class DocumentDeserializerImpl
           throw sOE;
        }
        catch(Exception e){
-              System.out.println("An error occured in the transformation : "+e);
+              System.out.println("An error occurred in the transformation : "+e);
        }
         return baos;
      }
diff --git a/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentSerializerImpl.java b/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentSerializerImpl.java
index feb8f7f..07bb934 100644
--- a/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentSerializerImpl.java
+++ b/xmerge/source/xmerge/java/org/openoffice/xmerge/converter/xml/xslt/DocumentSerializerImpl.java
@@ -287,7 +287,7 @@ public final class DocumentSerializerImpl
           */
        }
        catch(Exception e){
-              System.out.println("An error occured in the transformation : "+e);
+              System.out.println("An error occurred in the transformation : "+e);
        }
        return baos;
      }
commit 2802d8b841df661c81cdbbc3bb0e80d0bdd16823
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Sun Dec 5 13:15:51 2010 +0000

    cppcheck: uninit variables

diff --git a/binfilter/bf_sfx2/source/doc/sfx2_objuno.cxx b/binfilter/bf_sfx2/source/doc/sfx2_objuno.cxx
index 0874572..adad753 100644
--- a/binfilter/bf_sfx2/source/doc/sfx2_objuno.cxx
+++ b/binfilter/bf_sfx2/source/doc/sfx2_objuno.cxx
@@ -507,8 +507,8 @@ using namespace ::com::sun::star::frame;
 /*N*/ 	}
 /*N*/ 	else if ( aValue.getValueType() == ::getCppuType((const sal_Int32*)0) )
 /*N*/ 	{
-/*N*/ 		long nIntVal ;
-/*N*/ 		aValue >>= nIntVal ;
+/*N*/ 		long nIntVal(0);
+/*N*/ 		aValue >>= nIntVal;
 /*N*/ 		switch ( nHandle )
 /*N*/ 		{
 /*N*/ 			case MID_DOCINFO_AUTOLOADSECS:
@@ -522,8 +522,8 @@ using namespace ::com::sun::star::frame;
 /*N*/ 	}
 /*N*/ 	else if ( aValue.getValueType() == ::getCppuType((const sal_Int16*)0) )
 /*N*/ 	{
-/*N*/ 		short nIntVal ;
-/*N*/ 		aValue >>= nIntVal ;
+/*N*/ 		short nIntVal(0);
+/*N*/ 		aValue >>= nIntVal;
 /*N*/ 		switch ( nHandle )
 /*N*/ 		{
 /*N*/ 			case MID_DOCINFO_REVISION:


More information about the Libreoffice-commits mailing list
diff --git a/binfilter/bf_xmloff/source/core/xmloff_xmlexp.cxx b/binfilter/bf_xmloff/source/core/xmloff_xmlexp.cxx
index 4891c46..2e4f820 100644
--- a/binfilter/bf_xmloff/source/core/xmloff_xmlexp.cxx
+++ b/binfilter/bf_xmloff/source/core/xmloff_xmlexp.cxx
@@ -503,8 +503,8 @@ sal_Bool SAL_CALL SvXMLExport::filter( const uno::Sequence< beans::PropertyValue
                   aSeq, e.Message, NULL );
     }
 
-    // return true only if no error occured
-    return (GetErrorFlags() & (ERROR_DO_NOTHING|ERROR_ERROR_OCCURED)) == 0;
+    // return true only if no error occurred
+    return (GetErrorFlags() & (ERROR_DO_NOTHING|ERROR_ERROR_OCCURRED)) == 0;
 }
 
 void SAL_CALL SvXMLExport::cancel() throw(uno::RuntimeException)
@@ -1611,9 +1611,9 @@ void SvXMLExport::SetError(
 
     // maintain error flags
     if ( ( nId & XMLERROR_FLAG_ERROR ) != 0 )
-        mnErrorFlags |= ERROR_ERROR_OCCURED;
+        mnErrorFlags |= ERROR_ERROR_OCCURRED;
     if ( ( nId & XMLERROR_FLAG_WARNING ) != 0 )
-        mnErrorFlags |= ERROR_WARNING_OCCURED;
+        mnErrorFlags |= ERROR_WARNING_OCCURRED;
     if ( ( nId & XMLERROR_FLAG_SEVERE ) != 0 )
         mnErrorFlags |= ERROR_DO_NOTHING;
 